package com.demo;

import java.awt.Color;
import java.awt.BasicStroke;

import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.ChartFactory;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.plot.XYPlot;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.data.xy.XYDataset;
import org.jfree.ui.RectangleInsets;
import org.jfree.ui.ApplicationFrame;
import org.jfree.ui.RefineryUtilities;
import org.jfree.chart.renderer.xy.XYSplineRenderer;

public class LineChart3 extends ApplicationFrame
{
	private static final long serialVersionUID = 1L;

    public LineChart3(final String title) 
    {
    	 super(title);

         JFreeChart  chart      = createChart();
         ChartPanel  chartPanel = new ChartPanel(chart);
         
         chartPanel.setPreferredSize(new java.awt.Dimension(560, 480));
         setContentPane(chartPanel);
    }

    private JFreeChart createChart()
    {
        final JFreeChart chart = ChartFactory.createXYLineChart(
            "Демонстрация Spline Renderer",
            null,                        // x axis label
            null,                        // y axis label
            null,                        // data
            PlotOrientation.VERTICAL,
            true,                        // include legend
            false,                       // tooltips
            false                        // urls
        );

        chart.setBackgroundPaint(Color.white);

        final XYPlot plot = chart.getXYPlot();
        plot.setBackgroundPaint(new Color(232, 232, 232));

        plot.setDomainGridlinePaint(Color.gray);
        plot.setRangeGridlinePaint (Color.gray);
        
        // Определение отступа меток делений
        plot.setAxisOffset(new RectangleInsets (1.0, 1.0, 1.0, 1.0));

        // Скрытие осевых линий и меток делений
        ValueAxis axis = plot.getDomainAxis();
        axis.setAxisLineVisible (false);    // осевая линия
        
        // Настройка NumberAxis
        final NumberAxis rangeAxis = (NumberAxis) plot.getRangeAxis();
        rangeAxis.setAxisLineVisible (false);
        rangeAxis.setStandardTickUnits(NumberAxis.createIntegerTickUnits());

        // Настройка XYSplineRenderer
        // Precision: the number of line segments between 2 points [default: 5]
        XYSplineRenderer r0 = new XYSplineRenderer();
        r0.setSeriesShapesVisible (0, false);
        
        XYSplineRenderer r1 = new XYSplineRenderer();
        r1.setPrecision(8); 
        r1.setSeriesShapesVisible (0, false);
        
        XYSplineRenderer r2 = new XYSplineRenderer(3);
        
        r2.setSeriesShapesVisible (0, false);
        r2.setSeriesPaint         (0, Color.orange);
        r2.setSeriesStroke        (0, new BasicStroke(2.5f));
        
        // Наборы данных
        XYDataset dataset0 = Dataset.createDataset2(0);
        XYDataset dataset1 = Dataset.createDataset2(1);
        XYDataset dataset2 = Dataset.createDataset2(2);
        
        plot.setDataset(0, dataset0);
        plot.setDataset(1, dataset1);
        plot.setDataset(2, dataset2);

        // Подключение Spline Renderer к наборам данных
        plot.setRenderer(0, r0);
        plot.setRenderer(1, r1);
        plot.setRenderer(2, r2);
        
        return chart;
    }
    
    public static void main(final String[] args) 
    {
        final LineChart3 demo = new LineChart3("XYSplineRenderer");
        demo.pack();
        RefineryUtilities.centerFrameOnScreen(demo);
        demo.setVisible(true);
    }
}
